# Eth Miner 

Basic Ethereum Miner Library. 

Developers can integrate this algorithm to mine blocks from their ethereum supported chain efficiently.


# Functionality 

This Algorithm can be implemented for #EthTrade for more functionality and interaction with the live Ethereum Chain.
